@@ -1,14 +1,17 @@
 # helpers.py
 import os
+from pathlib import Path
+
 from akerbp.mlops.core import logger
 
 
 logging=logger.get_logger(name='mlops_core')
 
 def get_top_folder(s):
-    if not isinstance(s, str):
-            s=str(s)
-    return s.split(os.sep)[0]
+    if isinstance(s, str):
+        return s.split(os.sep)[0]
+    elif isinstance(s, Path):
+        return s.parents[len(s.parents)-2]
 
 
 def as_import_path(file_path):
